==> sw-ui-bootstrap-1.0.6.tgz: package/README.md <==
# sw-ui-bootstrap
### [AngularJS](http://angularjs.org/) directives for Bootstrap [![Build Status: Windows](https://ci.appveyor.com/api/projects/status/dbr29smi3j8m8wd8/branch/master?svg=true)](https://ci.appveyor.com/project/gruntjs/sw-ui-bootstrap/branch/master)
[![NPM Version][npm-image]][npm-url]
[![NPM Downloads][downloads-image]][downloads-url]
[![NuGet version][nuget-image]][nuget-url]

### Getting Started

```
npm install sw-ui-bootstrap --save-dev
```

### [AngularJS Common][nuget-url]
```
PM> Install-Package sw-ui-bootstrap
```

### Dependencies
[ui.bootstrap](http://angular-ui.github.io/bootstrap/)

### Modules	
#### [form](http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.form)
This module contains form controls
<div>
	<dl>
		<dt><a href="http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.form.directive:swFormField">swFormField</a> </dt>
		<dd>Renders a form field. The following field types are supported: text, date</dd>
	</dl>
</div>

#### [route](http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.route)
This module contains directives that listen to the AngularJS $route events such as the $routeChangeStart event
<div>
	<dl>
		<dt><a href="http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.route.directive:head">head</a> </dt>
		<dd>Directive inspired by [angular-route-styles](https://github.com/tennisgent/angular-route-styles). It supports media formats as well.</dd>
	</dl>
</div>

[npm-image]: https://img.shields.io/npm/v/sw-ui-bootstrap.svg
[npm-url]: https://npmjs.org/package/sw-ui-bootstrap
[downloads-image]: https://img.shields.io/npm/dm/sw-ui-bootstrap.svg
[downloads-url]: https://npmjs.org/package/sw-ui-bootstrap
[nuget-image]: https://badge.fury.io/nu/sw-ui-bootstrap.png
[nuget-url]: https://www.nuget.org/packages/sw-ui-bootstrap/

==> sw-ui-bootstrap-1.0.13.tgz: package/README.md <==
# sw-ui-bootstrap
### [AngularJS](http://angularjs.org/) directives for Bootstrap [![Build Status: Windows](https://ci.appveyor.com/api/projects/status/dbr29smi3j8m8wd8/branch/master?svg=true)](https://ci.appveyor.com/project/gruntjs/sw-ui-bootstrap/branch/master)
[![NPM Version][npm-image]][npm-url]
[![NPM Downloads][downloads-image]][downloads-url]
[![NuGet version][nuget-image]][nuget-url]

### Getting Started

```
npm install sw-ui-bootstrap --save-dev
```

### [AngularJS Common][nuget-url]
```
PM> Install-Package sw-ui-bootstrap
```

### Dependencies
[ui.bootstrap](http://angular-ui.github.io/bootstrap/)

### Modules	
#### [form](http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.form)
This module contains form controls
<div>
	<dl>
		<dt><a href="http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.form.directive:swFormField">swFormField</a> </dt>
		<dd>Renders a form field. The following field types are supported: text, date</dd>
	</dl>
</div>

<hr/>

#### [route](http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.route)
This module contains directives that listen to the AngularJS $route events such as the $routeChangeStart event
<div>
	<dl>
		<dt><a href="http://swaksoft.com/docs/directives/docs/#/api/sw.ui.bootstrap.route.directive:head">head</a> </dt>
		<dd>Directive inspired by <a href="https://github.com/tennisgent/angular-route-styles">angular-route-styles</a>. It supports media formats as well.</dd>
	</dl>
</div>

[npm-image]: https://img.shields.io/npm/v/sw-ui-bootstrap.svg
[npm-url]: https://npmjs.org/package/sw-ui-bootstrap
[downloads-image]: https://img.shields.io/npm/dm/sw-ui-bootstrap.svg
[downloads-url]: https://npmjs.org/package/sw-ui-bootstrap
[nuget-image]: https://badge.fury.io/nu/sw-ui-bootstrap.png
[nuget-url]: https://www.nuget.org/packages/sw-ui-bootstrap/
